@@ -1,7 +1,7 @@
 ## function to calculate percentiles from time series data
 ## For SINGLE pollutants and MULTIPLE percentile values
 
-calcPercentile <- function(mydata, pollutant = "o3", period = "month", percentile = 50,
+calcPercentile <- function(mydata, pollutant = "o3", avg.time = "month", percentile = 50,
                             data.thresh = 0, start = NA) {
     site <- FALSE
     if ("site" %in% names(mydata)) {
@@ -9,10 +9,10 @@ calcPercentile <- function(mydata, pollutant = "o3", period = "month", percentil
         site.name <- mydata$site[1]
     }
 
-    make.percentile <- function(mydata, pollutant = "o3", period = "month", percentile = 50,
+    make.percentile <- function(mydata, pollutant = "o3", avg.time = "month", percentile = 50,
                                 data.thresh = 0, start = NA) {
 
-        mydata <- timeAverage(mydata, period, statistic = "percentile", percentile = percentile,
+        mydata <- timeAverage(mydata, avg.time, statistic = "percentile", percentile = percentile,
                                data.thresh = 0, start.date = NA)
         ## change column name
         new.name <-  paste("percentile.", percentile,  sep = "")
@@ -26,7 +26,7 @@ calcPercentile <- function(mydata, pollutant = "o3", period = "month", percentil
     }
 
     mydata <- lapply(percentile, function(x) make.percentile(mydata, pollutant = pollutant,
-                                                               period = period, percentile = x))
+                                                               avg.time = avg.time, percentile = x))
     mydata <- Reduce(function(x, y, by = 'date') merge(x, y, by = 'date', all = TRUE), mydata)
 
     if (site) mydata$site <- site.name
