@@ -27,7 +27,7 @@ find.time.interval <- function(dates) {
     ## could have several sites, dates may be unordered
     ## find the most common time gap in all the data
     dates <- unique(dates)  ## make sure they are unique
- 
+
     id <- which.max(table(diff(as.numeric(dates[order(dates)]))))
     seconds <- as.numeric(names(id))
 
@@ -153,7 +153,7 @@ splitByDate <- function(mydata, dates = "1/1/2003", labels = c("before", "after"
         }
     }
 
-    mydata <- checkPrep(mydata, names(mydata), "default")
+    mydata <- checkPrep(mydata, names(mydata), "default", remove.calm = FALSE)
     ## check there are sufficent labels for number of dates
     if (length(dates) != length(labels) - 1) {
         stop("There is a mis-match between dates and labels. There should be
@@ -196,18 +196,18 @@ one more label than date")
 #############################################################################################
 
 ## function to make it easy to use d/m/y format for subsetting by date
-selectByDate <- function (mydata, start = "1/1/2008", end = "31/12/2008", year = 2008, 
+selectByDate <- function (mydata, start = "1/1/2008", end = "31/12/2008", year = 2008,
     month = 1, day = "weekday", hour = 1, use.local.tz = TRUE)
 
 {
      ## extract variables of interest
     vars <- names(mydata)
-    ## useful to check to see if local time zones are used, which would affect by hour extraction
-    mydata <- checkPrep(mydata, vars, type = "default")
-    
+
     weekday.names <- format(ISOdate(2000, 1, 3:9), "%A")
     my.tz <- if(use.local.tz)
-        format(mydata$date, "%Z")[1] else "GMT"
+
+        attr(mydata$date, "tzone") <- attr(mydata$date, "tzone") else  attr(mydata$date, "tzone") <- "GMT"
+
     if (!missing(start) & !missing(end)) {
         start <- as.POSIXct(strptime(start, format = "%d/%m/%Y"), my.tz)
         end <- as.POSIXct(strptime(end, format = "%d/%m/%Y"), my.tz) + (23 * 3600)
@@ -221,7 +221,7 @@ selectByDate <- function (mydata, start = "1/1/2008", end = "31/12/2008", year =
             mydata <- mydata[as.numeric(format(mydata$date, "%m")) %in% month, ]
         }
         else {
-            mydata <- subset(mydata, substr(tolower(format(date, 
+            mydata <- subset(mydata, substr(tolower(format(date,
                 "%B")), 1, 3) %in% substr(tolower(month), 1, 3))
         }
     }
@@ -230,11 +230,11 @@ selectByDate <- function (mydata, start = "1/1/2008", end = "31/12/2008", year =
     }
     if (!missing(day)) {
         days <- day
-        if (day[1] == "weekday") 
+        if (day[1] == "weekday")
             days <- weekday.names[1:5]
-        if (day[1] == "weekend") 
+        if (day[1] == "weekend")
             days <- weekday.names[6:7]
-        mydata <- subset(mydata, substr(tolower(format(date, 
+        mydata <- subset(mydata, substr(tolower(format(date,
             "%A")), 1, 3) %in% substr(tolower(days), 1, 3))
     }
     mydata
@@ -332,7 +332,7 @@ panel.gam <- function (x, y, form = y ~ x, method = "loess", ..., simulate = FAL
                        type, col.line, col.symbol, fill, pch, cex, font, fontface,
                        fontfamily)
 {
-    
+
     ## panel function to add a smooth line to a plot
     ## Uses a GAM (mgcv) to fit smooth
     ## Optionally can plot 95% confidence intervals and run bootstrap simulations
@@ -363,7 +363,7 @@ panel.gam <- function (x, y, form = y ~ x, method = "loess", ..., simulate = FAL
         } else { ## simulations required
 
             sam.size <- length(x)
-            print(sam.size)
+
             lims <- current.panel.limits()
             xrange <- c(max(min(lims$x), min(x)), min(max(lims$x), max(x)))
             xseq <- seq(xrange[1], xrange[2], length = sam.size)
@@ -389,7 +389,7 @@ panel.gam <- function (x, y, form = y ~ x, method = "loess", ..., simulate = FAL
                 ## make new data
                 new.data <- data.frame(x = xseq, y = pred.input + residuals[index[, i]])
 
-                mod <- gam(y ~ s(x),  data = new.data)
+                mod <- gam(y ~ s(x), data = new.data)
 
                 pred <- predict(mod, new.data)
 
@@ -472,16 +472,75 @@ panel.linear <- function (x, y, form = y ~ x, method = "loess", x.nam, y.nam, ..
 
 ## error in mean from Hmisc
 
-errorInMean <- function (x, mult = qt((1 + conf.int)/2, n - 1), conf.int = 0.95, 
-                         na.rm = TRUE) 
+errorInMean <- function (x, mult = qt((1 + conf.int)/2, n - 1), conf.int = 0.95,
+                         na.rm = TRUE)
 {
-    if (na.rm) 
+    if (na.rm)
         x <- x[!is.na(x)]
     n <- length(x)
-    if (n < 2) 
+    if (n < 2)
         return(c(Mean = mean(x), Lower = NA, Upper = NA))
     xbar <- sum(x)/n
     se <- sqrt(sum((x - xbar)^2)/n/(n - 1))
-    c(Mean = xbar, Lower = xbar - mult * se, Upper = xbar + mult * 
+    c(Mean = xbar, Lower = xbar - mult * se, Upper = xbar + mult *
       se)
 }
+
+
+###########################################################################################################
+
+## list update function
+## for lattice type object structure and ... handling
+
+## (currently used by)
+## (all openair plots that include colorkey controlled by drawOpenKey)
+
+##listUpdate function
+#[in development]
+listUpdate <- function(a, b, drop.dots = TRUE,
+                       subset.a = NULL, subset.b = NULL){
+    if(drop.dots){
+        a <- a[names(a) != "..."]
+        b <- b[names(b) != "..."]
+    }
+    if(!is.null(subset.a))
+        a <- a[names(a) %in% subset.a]
+    if(!is.null(subset.b))
+        b <- b[names(b) %in% subset.b]
+    if(length(names(b) > 0))
+        a <- modifyList(a, b)
+    a
+}
+
+#############################################################################################################
+
+## makeOpenKeyLegend v0.1
+
+##common code for making legend list
+##objects for use with drawOpenkey outputs
+
+##uses listUpdate in utilities
+
+makeOpenKeyLegend <- function(key, default.key, fun.name = "function"){
+    #handle logicals and lists
+    if (is.logical(key)) {
+        legend <- if (key) default.key else NULL
+    } else if (is.list(key)) {
+            legend <- listUpdate(default.key, key)
+        } else {
+            if(!is.null(key))
+                warning(paste("In ", fun.name, "(...):\n unrecognised key not exported/applied\n",
+                              " [see ?drawOpenKey for key structure/options]", sep = ""),
+                        call. = FALSE)
+            legend <- NULL
+    }
+
+    #structure like legend for drawOpenKey
+    if(!is.null(legend)){
+        legend <- list(right = list(fun = drawOpenKey, args = list(key = legend),
+                         draw =FALSE))
+        if("space" %in% names(legend$right$args$key))
+            names(legend)[[1]] <- legend$right$args$key$space
+    }
+    legend
+}
